"""
ilovetools - A comprehensive Python utility library
"""

__version__ = "0.1.7"
__author__ = "Ali Mehdi"
__email__ = "ali.mehdi.dev579@gmail.com"

# Import all modules for easy access
from . import ai
from . import data
from . import ml
from . import files
from . import text
from . import image
from . import audio
from . import web
from . import security
from . import database
from . import datetime
from . import validation
from . import conversion
from . import automation
from . import utils

__all__ = [
    "ai",
    "data",
    "ml",
    "files",
    "text",
    "image",
    "audio",
    "web",
    "security",
    "database",
    "datetime",
    "validation",
    "conversion",
    "automation",
    "utils",
]
